@@ -133,14 +133,12 @@ sub _parse_bag {
 }
 
 sub _parse_item {
-  my $item = hex_cast($_[0]);
+  my $item = shift;
   if (! ref $item) {
     eval { $item = SILK_IPADDR_CLASS->new($item) };
     if ($@) {
-      #print STDERR "NOT IP: $@\n";
       eval { $item = SILK_IPWILDCARD_CLASS->new($item) };
       if ($@) {
-        #print STDERR "NOT WILD: $@\n";
         Carp::confess "ip address, string, or number required: $item";
       }
     }
@@ -393,20 +391,20 @@ sub inversion {
 
 sub get {
   my $self = shift;
-  my $key  = hex_cast(shift);
+  my $key  = shift;
   return unless defined $key;
   Net::Silk::Bag::_get_val($self, $key) || 0;
 }
 
 sub set {
   my $self = shift;
-  my($key, $val) = ($_[0], hex_cast($_[1]));
+  my($key, $val) = ($_[0], $_[1]);
   Net::Silk::Bag::_set_val($self, $key, $val || 0);
 }
 
 sub incr {
   my $self = shift;
-  my($key, $val) = ($_[0], defined $_[1] ? hex_cast($_[1]) : 1);
+  my($key, $val) = ($_[0], defined $_[1] ? $_[1] : 1);
   my $res;
   eval { $res = Net::Silk::Bag::_incr_val($self, $key, $val || 1) };
   $res;
@@ -414,7 +412,7 @@ sub incr {
 
 sub decr {
   my $self = shift;
-  my($key, $val) = ($_[0], $_[1] ? hex_cast($_[1]) : 1);
+  my($key, $val) = ($_[0], $_[1] ? $_[1] : 1);
   if (my $cur = $self->get($key)) {
     if ($val >= $cur) {
       $self->del($key);
@@ -434,7 +432,7 @@ sub del {
 sub contains {
   my $self = shift;
   return 0 unless @_;
-  $self->get(hex_cast($_[0])) ? 1 : 0;
+  $self->get($_[0]) ? 1 : 0;
 }
 
 sub _fh_iter {
@@ -648,7 +646,7 @@ sub div {
 
 sub scalar_div {
   my $self = shift;
-  my $item = hex_cast(shift);
+  my $item = shift;
   croak "non-numeric scalar division unsupported"
     unless ref $item || looks_like_number($item);
   return $self unless $item > 1;
@@ -717,7 +715,7 @@ sub mul {
 
 sub scalar_mul {
   my $self = shift;
-  my $item = hex_cast(shift);
+  my $item = shift;
   croak "non-numeric scalar multiplication unsupported"
     unless ref $item || looks_like_number($item);
   my $new  = $self->new;
