@@ -50,8 +50,7 @@ use warnings;
 use Net::Silk qw( :basic );
 use Net::Silk::IPAddr;
 
-use Math::Int64  qw( uint64  );
-use Math::Int128 qw( uint128 );
+use Math::BigInt;
 
 use overload (
   '""'   => \&_str,
@@ -78,29 +77,21 @@ use overload (
 
 my %Attr;
 
-my $Fat_Int = SILK_IPV6_ENABLED ? sub { uint128(shift) }
-                                : sub {  uint64(shift) };
-
 sub _str { overload::StrVal($_[0]) }
 
 sub cardinality {
   my $self = shift;
-  my @blocks = $self->_cardinality;
-  my $c = $Fat_Int->(0);
-  foreach my $i (0 .. $#blocks) {
-    my $block = $blocks[$i];
-    my $bits = $Fat_Int->(0);
-    foreach my $j (0 .. $#$block) {
-      $bits += $block->[$j];
-    }
-    if ($c) {
-      $c *= $bits;
+  my $card;
+  eval { $card = $self->_cardinality };
+  if ($@) {
+    if ($@ =~ /overflow/) {
+      $card = Math::BigInt->new("0x100000000000000000000000000000000");
     }
     else {
-      $c = $bits;
+      croak $@;
     }
   }
-  $c;
+  $card;
 }
 
 sub iter {
@@ -221,7 +212,7 @@ Some examples of valid strings:
   '16909056'
   '16909056/24'
   '1.2.3.x'
-  '1:2:3:4:5:6:7.x'
+  '1:2:3:4:5:6:7:x'
   '1.2,3.4,5.6,7'
   '1.2.3.0-255'
   '::2-4'
