@@ -57,7 +57,7 @@ use overload (
 );
 
 use Net::Silk qw( :basic );
-use Net::Silk::Site qw( load_site HAVE_SITE_CONFIG );
+use Net::Silk::Site qw( HAVE_SITE_CONFIG_SILENT );
 use Net::Silk::IPAddr;
 
 use DateTime;
@@ -130,8 +130,10 @@ sub as_hash {
                  uniform_packets )) {
     $r{$m} = $self->$m;
   }
-  for my $m (qw( classtype_id classtype sensor_id sensor )) {
-    $r{$m} = $self->$m;
+  if (HAVE_SITE_CONFIG_SILENT()) {
+    for my $m (qw( classtype_id classtype sensor_id sensor )) {
+      $r{$m} = $self->$m;
+    }
   }
   my $prot = $self->protocol;
   if ($prot == 6 || $prot == 17 || $prot == 132) {
@@ -214,7 +216,7 @@ sub protocol {
 
 sub sensor {
   my $self = shift;
-  Net::Silk::Site::load_site() || return;
+  return unless HAVE_SITE_CONFIG_SILENT();
   if (@_) {
     my $sensor = shift;
     if (! looks_like_number($sensor)) {
@@ -235,19 +237,19 @@ sub sensor_id {
 
 sub classname {
   my $self = shift;
-  Net::Silk::Site::load_site() || return;
+  return unless HAVE_SITE_CONFIG_SILENT();
   $self->_classname();
 }
 
 sub typename {
   my $self = shift;
-  Net::Silk::Site::load_site() || return;
+  return unless HAVE_SITE_CONFIG_SILENT();
   $self->_typename();
 }
 
 sub classtype {
   my $self = shift;
-  Net::Silk::Site::load_site() || return;
+  return unless HAVE_SITE_CONFIG_SILENT();
   if (@_) {
     my $classtype;
     if (@_ > 1 || ref $_[0]) {
