@@ -166,7 +166,15 @@ sub load_site {
   $SITE_CONFIGURED = 1;
 }
 
-sub HAVE_SITE_CONFIG { $HAVE_SITE }
+sub HAVE_SITE_CONFIG { load_site(); $HAVE_SITE }
+
+sub HAVE_SITE_CONFIG_SILENT {
+  *SAVERR = *STDERR;
+  open(STDERR, ">/dev/null");
+  my $res = HAVE_SITE_CONFIG();
+  *STDERR = *SAVERR;
+  $res;
+}
 
 sub _sensors_by_id {
   my %sensors;
@@ -395,6 +403,7 @@ BEGIN {
     init_site
     load_site
     HAVE_SITE_CONFIG
+    HAVE_SITE_CONFIG_SILENT
     get_site_config
     get_data_rootdir
     set_data_rootdir
